==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/ModifyEbsDefaultKmsKeyIdRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.KmsKeyId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyEbsDefaultKmsKeyIdRequest(
    kmsKeyId: KmsKeyId,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyEbsDefaultKmsKeyIdRequest = {
    import ModifyEbsDefaultKmsKeyIdRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyEbsDefaultKmsKeyIdRequest
      .builder()
      .kmsKeyId(KmsKeyId.unwrap(kmsKeyId): java.lang.String)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ModifyEbsDefaultKmsKeyIdRequest.ReadOnly =
    zio.aws.ec2.model.ModifyEbsDefaultKmsKeyIdRequest.wrap(buildAwsValue())
}
object ModifyEbsDefaultKmsKeyIdRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyEbsDefaultKmsKeyIdRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyEbsDefaultKmsKeyIdRequest =
      zio.aws.ec2.model
        .ModifyEbsDefaultKmsKeyIdRequest(kmsKeyId, dryRun.map(value => value))
    def kmsKeyId: KmsKeyId
    def dryRun: Optional[Boolean]
    def getKmsKeyId: ZIO[Any, Nothing, KmsKeyId] = ZIO.succeed(kmsKeyId)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyEbsDefaultKmsKeyIdRequest
  ) extends zio.aws.ec2.model.ModifyEbsDefaultKmsKeyIdRequest.ReadOnly {
    override val kmsKeyId: KmsKeyId =
      zio.aws.ec2.model.primitives.KmsKeyId(impl.kmsKeyId())
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyEbsDefaultKmsKeyIdRequest
  ): zio.aws.ec2.model.ModifyEbsDefaultKmsKeyIdRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-5.19.17.1-sources.jar: zio/aws/ec2/model/ModifyEbsDefaultKmsKeyIdRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.KmsKeyId
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class ModifyEbsDefaultKmsKeyIdRequest(kmsKeyId: KmsKeyId) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyEbsDefaultKmsKeyIdRequest = {
    import ModifyEbsDefaultKmsKeyIdRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyEbsDefaultKmsKeyIdRequest
      .builder()
      .kmsKeyId(KmsKeyId.unwrap(kmsKeyId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ModifyEbsDefaultKmsKeyIdRequest.ReadOnly =
    zio.aws.ec2.model.ModifyEbsDefaultKmsKeyIdRequest.wrap(buildAwsValue())
}
object ModifyEbsDefaultKmsKeyIdRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyEbsDefaultKmsKeyIdRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyEbsDefaultKmsKeyIdRequest =
      zio.aws.ec2.model.ModifyEbsDefaultKmsKeyIdRequest(kmsKeyId)
    def kmsKeyId: KmsKeyId
    def getKmsKeyId: ZIO[Any, Nothing, KmsKeyId] = ZIO.succeed(kmsKeyId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyEbsDefaultKmsKeyIdRequest
  ) extends zio.aws.ec2.model.ModifyEbsDefaultKmsKeyIdRequest.ReadOnly {
    override val kmsKeyId: KmsKeyId =
      zio.aws.ec2.model.primitives.KmsKeyId(impl.kmsKeyId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyEbsDefaultKmsKeyIdRequest
  ): zio.aws.ec2.model.ModifyEbsDefaultKmsKeyIdRequest.ReadOnly = new Wrapper(
    impl
  )
}
